#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for vbox services on EIS/FAIR
#
# Copyright (c) 2002-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2002-07-27  jed
# Last Update:  $Id: install.sh 59159 2018-10-28 06:35:28Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

module_name="vbox"

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2> /tmp/${module_name}-install.sh-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

installfile=/var/run/$module_name.install
archivefile=/var/run/$module_name-backup.tgz

mecho --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

### symbolic links
mecho "creating symbolic links ..."

rm -f /etc/rc2.d/[KS]??${module_name}

ln -sf /etc/init.d/${module_name} /etc/rc2.d/K20${module_name}
ln -sf /etc/init.d/${module_name} /etc/rc2.d/S80${module_name}

cd /usr/local/vbox/bin
ln -sf vboxcnvt autovbox
ln -sf vboxcnvt vboxmode
ln -sf vboxcnvt vboxtoau

# make sure that symbolic library links exist
ldconfig -n /usr/lib 2>/dev/null

#create directories
mkdir -p /var/spool/vbox
mkdir -p /usr/local/vbox/etc

# add menu entry
mecho "adding menu ..."
/var/install/bin/add-menu --menu "setup.services.menu" "setup.services.$module_name.menu" "VBox Service"

# move old files to backup directory and create backup
/var/install/bin/backup-file --quiet $module_name

if [ -f $installfile ]
then
    # previous version found - upgrading
    if [ -f $archivefile ]
    then
        mecho "restoring directory content of /var/spool/vbox ..."
        cd /
        tar xzf $archivefile 2>/dev/null
        rm -f $archivefile
    fi

    # check if 'old' standard.tcl files exist
    sfile=standard.tcl

    find /var/spool/vbox -name ${sfile} | while read line
    do
        # search for standard.tcl files
        if [ -n "${line}" ]
        then
            # file found ...
            grep -q "\$vbox_var_bindir\/" ${line}

            if [ $? -eq 0 ]
            then
                # variable found, replace it ...
                if [ ! -f ${line}.backup ]
                then
                    echo "${line}"
                    cp ${line} ${line}.backup

                    sed 's#\$vbox_var_bindir\/#\/usr\/local\/vbox\/bin\/#g' ${line}.backup > ${line}
                fi
            fi
        fi
    done
fi

# install/update package configuration file
update=false
if install_config ${module_name}
then
    update=true
fi

# configuration
mecho "creating ${module_name} configuration ..."

if [ "${update}" = "true" ]
then
    # updated installation
    /var/install/config.d/${module_name}.sh
    if [ -f /etc/init.d/${module_name} ]
    then
        /etc/init.d/${module_name} restart
    fi
else
    # new installation
    /var/install/bin/edit --apply "${module_name}" "Edit ${module_name} services configuration"
fi

exit 0
